# **ssw-py** documentation

**ssw-py** is a Python wrappers for the

## Contents

```{toctree}
:maxdepth: 2

quickstart
api/index
changes_link
```

## Indices and tables

- {ref}`genindex`
- {ref}`modindex`
- {ref}`search`
